@@ -7,7 +7,7 @@ use unrar::Archive;
 use crate::{
     error::{Error, Result},
     list::FileInArchive,
-    utils::logger::info,
+    utils::{logger::info, Bytes},
 };
 
 /// Unpacks the archive given by `archive_path` into the folder given by `output_folder`.
@@ -18,7 +18,7 @@ pub fn unpack_archive(
     password: Option<&[u8]>,
     quiet: bool,
 ) -> crate::Result<usize> {
-    assert!(output_folder.read_dir().expect("dir exists").count() == 0);
+    assert!(output_folder.read_dir().expect("dir exists").next().is_none());
 
     let archive = match password {
         Some(password) => Archive::with_password(archive_path, password),
@@ -33,9 +33,9 @@ pub fn unpack_archive(
         archive = if entry.is_file() {
             if !quiet {
                 info(format!(
-                    "{} extracted. ({})",
+                    "extracted ({}) {}",
+                    Bytes::new(entry.unpacked_size),
                     entry.filename.display(),
-                    entry.unpacked_size
                 ));
             }
             unpacked += 1;
