@@ -10,10 +10,12 @@ use std::{
 
 use crate::{
     error::FinalError,
-    extension::{build_archive_file_suggestion, Extension, PRETTY_SUPPORTED_ALIASES, PRETTY_SUPPORTED_EXTENSIONS},
-    info,
-    utils::{pretty_format_list_of_paths, try_infer_extension, user_wants_to_continue, EscapedPathDisplay},
-    warning, QuestionAction, QuestionPolicy, Result,
+    extension::{build_archive_file_suggestion, Extension},
+    utils::{
+        logger::{info_accessible, warning},
+        pretty_format_list_of_paths, try_infer_extension, user_wants_to_continue, EscapedPathDisplay,
+    },
+    QuestionAction, QuestionPolicy, Result,
 };
 
 /// Check if the mime type matches the detected extensions.
@@ -33,12 +35,11 @@ pub fn check_mime_type(
         if let Some(detected_format) = try_infer_extension(path) {
             // Inferring the file extension can have unpredicted consequences (e.g. the user just
             // mistyped, ...) which we should always inform the user about.
-            info!(
-                accessible,
-                "Detected file: `{}` extension as `{}`",
+            warning(format!(
+                "We detected a file named `{}`, do you want to decompress it?",
                 path.display(),
-                detected_format
-            );
+            ));
+
             if user_wants_to_continue(path, question_policy, QuestionAction::Decompression)? {
                 formats.push(detected_format);
             } else {
@@ -54,11 +55,11 @@ pub fn check_mime_type(
             .compression_formats
             .ends_with(detected_format.compression_formats)
         {
-            warning!(
+            warning(format!(
                 "The file extension: `{}` differ from the detected extension: `{}`",
-                outer_ext,
-                detected_format
-            );
+                outer_ext, detected_format
+            ));
+
             if !user_wants_to_continue(path, question_policy, QuestionAction::Decompression)? {
                 return Ok(ControlFlow::Break(()));
             }
@@ -66,11 +67,10 @@ pub fn check_mime_type(
     } else {
         // NOTE: If this actually produces no false positives, we can upgrade it in the future
         // to a warning and ask the user if he wants to continue decompressing.
-        info!(
-            accessible,
+        info_accessible(format!(
             "Failed to confirm the format of `{}` by sniffing the contents, file might be misnamed",
             path.display()
-        );
+        ));
     }
     Ok(ControlFlow::Continue(()))
 }
@@ -159,10 +159,8 @@ pub fn check_missing_formats_when_decompressing(files: &[PathBuf], formats: &[Ve
         ));
     }
 
-    error = error
-        .detail("Decompression formats are detected automatically from file extension")
-        .hint(format!("Supported extensions are: {}", PRETTY_SUPPORTED_EXTENSIONS))
-        .hint(format!("Supported aliases are: {}", PRETTY_SUPPORTED_ALIASES));
+    error = error.detail("Decompression formats are detected automatically from file extension");
+    error = error.hint_all_supported_formats();
 
     // If there's exactly one file, give a suggestion to use `--format`
     if let &[path] = files_with_broken_extension.as_slice() {
