@@ -1,6 +1,3 @@
-// Macros should be declared first
-pub mod macros;
-
 pub mod accessible;
 pub mod archive;
 pub mod check;
@@ -14,9 +11,15 @@ pub mod utils;
 use std::{env, path::PathBuf};
 
 use cli::CliArgs;
-use error::{Error, Result};
 use once_cell::sync::Lazy;
-use utils::{QuestionAction, QuestionPolicy};
+
+use self::{
+    error::{Error, Result},
+    utils::{
+        logger::{shutdown_logger_and_wait, spawn_logger_thread},
+        QuestionAction, QuestionPolicy,
+    },
+};
 
 // Used in BufReader and BufWriter to perform less syscalls
 const BUFFER_CAPACITY: usize = 1024 * 32;
@@ -28,7 +31,11 @@ static CURRENT_DIRECTORY: Lazy<PathBuf> = Lazy::new(|| env::current_dir().unwrap
 pub const EXIT_FAILURE: i32 = libc::EXIT_FAILURE;
 
 fn main() {
-    if let Err(err) = run() {
+    spawn_logger_thread();
+    let result = run();
+    shutdown_logger_and_wait();
+
+    if let Err(err) = result {
         eprintln!("{err}");
         std::process::exit(EXIT_FAILURE);
     }
