@@ -1,7 +1,11 @@
 #[macro_use]
 mod utils;
 
-use std::{io::Write, iter::once, path::PathBuf};
+use std::{
+    io::Write,
+    iter::once,
+    path::{Path, PathBuf},
+};
 
 use fs_err as fs;
 use parse_display::Display;
@@ -377,10 +381,9 @@ fn multiple_files_with_disabled_smart_unpack_by_dir(
     let files_path = ["file1.txt", "file2.txt", "file3.txt", "file4.txt", "file5.txt"]
         .into_iter()
         .map(|f| src_files_path.join(f))
-        .map(|path| {
-            let mut file = fs::File::create(&path).unwrap();
+        .inspect(|path| {
+            let mut file = fs::File::create(path).unwrap();
             file.write_all("Some content".as_bytes()).unwrap();
-            path
         })
         .collect::<Vec<_>>();
 
@@ -467,3 +470,137 @@ fn unpack_rar_stdin() -> Result<(), Box<dyn std::error::Error>> {
 
     Ok(())
 }
+
+#[proptest(cases = 25)]
+fn symlink_pack_and_unpack(
+    ext: DirectoryExtension,
+    #[any(size_range(0..1).lift())] extra_extensions: Vec<FileExtension>,
+) {
+    if matches!(ext, DirectoryExtension::SevenZ) {
+        // Skip 7z because the 7z format does not support symlinks
+        return Ok(());
+    }
+
+    let temp_dir = tempdir()?;
+    let root_path = temp_dir.path();
+
+    let src_files_path = root_path.join("src_files");
+    fs::create_dir_all(&src_files_path)?;
+
+    let mut files_path = ["file1.txt", "file2.txt", "file3.txt", "file4.txt", "file5.txt"]
+        .into_iter()
+        .map(|f| src_files_path.join(f))
+        .map(|path| {
+            let mut file = fs::File::create(&path).unwrap();
+            file.write_all("Some content".as_bytes()).unwrap();
+            path
+        })
+        .collect::<Vec<_>>();
+
+    let dest_files_path = root_path.join("dest_files");
+    fs::create_dir_all(&dest_files_path)?;
+
+    let symlink_path = src_files_path.join(Path::new("symlink"));
+    #[cfg(unix)]
+    std::os::unix::fs::symlink(&files_path[0], &symlink_path)?;
+    #[cfg(windows)]
+    std::os::windows::fs::symlink_file(&files_path[0], &symlink_path)?;
+
+    files_path.push(symlink_path);
+
+    let archive = &root_path.join(format!("archive.{}", merge_extensions(&ext, extra_extensions)));
+
+    crate::utils::cargo_bin()
+        .arg("compress")
+        .args(files_path.clone())
+        .arg(archive)
+        .assert()
+        .success();
+
+    crate::utils::cargo_bin()
+        .arg("decompress")
+        .arg(archive)
+        .arg("-d")
+        .arg(&dest_files_path)
+        .assert()
+        .success();
+
+    assert_same_directory(&src_files_path, &dest_files_path, false);
+    // check the symlink stand still
+    for f in dest_files_path.as_path().read_dir()? {
+        let f = f?;
+        if f.file_name() == "symlink" {
+            assert!(f.file_type()?.is_symlink())
+        }
+    }
+
+    fs::remove_file(archive)?;
+    fs::remove_dir_all(&dest_files_path)?;
+
+    crate::utils::cargo_bin()
+        .arg("compress")
+        .arg("--follow-symlinks")
+        .args(files_path)
+        .arg(archive)
+        .assert()
+        .success();
+
+    crate::utils::cargo_bin()
+        .arg("decompress")
+        .arg(archive)
+        .arg("-d")
+        .arg(&dest_files_path)
+        .assert()
+        .success();
+
+    // check there is no symlinks
+    for f in dest_files_path.as_path().read_dir()? {
+        let f = f?;
+        assert!(!f.file_type().unwrap().is_symlink())
+    }
+}
+
+#[test]
+fn no_git_folder_after_decompression_with_gitignore_flag_active() {
+    use std::process::Command;
+
+    let dir = tempdir().unwrap();
+    let dir_path = dir.path();
+
+    let before = dir_path.join("before");
+
+    let decompressed = dir_path.join("decompressed");
+
+    // Create directory and a dummy file
+    fs::create_dir(&before).unwrap();
+    fs::write(before.join("hello.txt"), b"Hello, world!").unwrap();
+
+    // Run `git init` inside it
+    Command::new("git")
+        .arg("init")
+        .current_dir(&before)
+        .output()
+        .expect("failed to run git init");
+
+    assert!(before.join(".git").exists(), ".git folder should exist after git init");
+
+    // Compress it
+    let archive = dir_path.join("archive.zip");
+    ouch!("c", &before, &archive, "--gitignore");
+
+    // Decompress it
+    ouch!("d", &archive, "-d", &decompressed);
+
+    // Find the subdirectory inside decompressed (e.g., "before")
+    let decompressed_subdir = fs::read_dir(&decompressed)
+        .unwrap()
+        .find_map(Result::ok)
+        .map(|entry| entry.path())
+        .expect("Expected one directory inside decompressed");
+
+    // Assert that the decompressed folder does not include `.git/`
+    assert!(
+        !decompressed_subdir.join(".git").exists(),
+        ".git folder should not exist after decompression"
+    );
+}
